@@ -1,4 +1,3 @@
-
 # Run with pytest.
 
 # pylint: disable=missing-function-docstring,redefined-outer-name,unidiomatic-typecheck
@@ -795,6 +794,45 @@ def test_rset_columns(cnxn):
     assert rset.columns == ('a', 'b', 'c')
 
 
+def test_rset_colinfos(cnxn):
+    cnxn.execute(
+        """
+        create table t1(
+          a int4,
+          b text,
+          c date,
+          d timestamptz,
+          e decimal(19, 2)
+        )
+        """)
+
+    values = [1, 'one', '2001-01-01', '2001-01-01 12:34', '3.14']
+    cnxn.execute("insert into t1 values ($1, $2, $3, $4, $5)", *values)
+    rset = cnxn.fetchall("select * from t1")
+
+    expected_infos = [
+        ('a', 'int4'),
+        ('b', 'text'),
+        ('c', 'date'),
+        ('d', 'timestamptz'),
+        ('e', 'decimal'),
+    ]
+
+    for actual, expected in zip(rset.colinfos, expected_infos):
+        # Convert the actual to an info_t.  There are some values we don't know
+        # what the value should be like OIDs.
+
+        assert actual.name == expected[0]
+
+        typename = cnxn.fetchval(
+            """
+            select typname
+              from pg_type
+             where oid = $1
+            """, actual.type)
+        assert typename == expected[1]
+
+
 def test_row_columns(cnxn):
     cnxn.execute("create table t1(a int, b int, c int)")
     cnxn.execute("insert into t1 values (1,1,1)")
@@ -1054,6 +1092,7 @@ def test_empty_json(cnxn):
     result = cnxn.fetchval("select j from t1")
     assert value == result
 
+
 def test_jsonb(cnxn):
 
     value = {
